@@ -1026,7 +1026,9 @@ class Interpreter:
             else:
                 val = val.Value[i.Value]
         if expr.Right is not None and expr.Right.ExprType == types.ExprTypes.NewArrayIndex:
-            raise exceptions.RuntimeError(f'Append not supported. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)    
+            raise exceptions.RuntimeError(f'Append not supported. ({var.Name}{index_as_str}).', ind.Token.Location, self.filename)
+        print("Indexed")
+        print("val: ", val.Type, " ", val.Value)
         return val
 
 
