@@ -45,4 +45,7 @@ class LexToken:
 
     def Clone(self):
         return copy.deepcopy(self)
-    
\ No newline at end of file
+    
+    @staticmethod
+    def nullToken():
+        return LexToken("Nil", types.LexTokenTypes.Nil, location.nullLoc(), -1)
\ No newline at end of file
